@@ -41,24 +41,42 @@ G_BEGIN_DECLS
 #define CHEESE_EFFECT_GET_CLASS(obj) \
   (G_TYPE_INSTANCE_GET_CLASS ((obj), CHEESE_TYPE_EFFECT, CheeseEffectClass))
 
-typedef struct
-{
-  GObject parent;
-} CheeseEffect;
+typedef struct _CheeseEffectPrivate CheeseEffectPrivate;
+typedef struct _CheeseEffectClass CheeseEffectClass;
+typedef struct _CheeseEffect CheeseEffect;
 
-typedef struct
+/**
+ * CheeseEffectClass:
+ *
+ * Use the accessor functions below.
+ */
+struct _CheeseEffectClass
 {
+  /*< private >*/
   GObjectClass parent_class;
-} CheeseEffectClass;
+};
 
-GType cheese_effect_get_type (void);
+/**
+ * CheeseEffect:
+ *
+ * Use the accessor functions below.
+ */
+struct _CheeseEffect
+{
+  /*< private >*/
+  GObject parent;
+  CheeseEffectPrivate *priv;
+};
 
-CheeseEffect *cheese_effect_new (void);
-gboolean      cheese_effect_is_preview_connected (CheeseEffect *self);
-void          cheese_effect_enable_preview (CheeseEffect *self);
-void          cheese_effect_disable_preview (CheeseEffect *self);
+GType cheese_effect_get_type (void) G_GNUC_CONST;
 
-CheeseEffect *cheese_effect_load_from_file (const gchar *fname);
+CheeseEffect *cheese_effect_new (const gchar *name,
+                                 const gchar *pipeline_desc);
+gboolean      cheese_effect_is_preview_connected (CheeseEffect *effect);
+void          cheese_effect_enable_preview (CheeseEffect *effect);
+void          cheese_effect_disable_preview (CheeseEffect *effect);
+
+CheeseEffect *cheese_effect_load_from_file (const gchar *filename);
 GList        *cheese_effect_load_effects (void);
 
 G_END_DECLS
